==> xsns_1.0.0.zip: xsns_1.0.0/xoops_trust_path/modules/xsns/language/japanese/admin.php <==
<?php

define('_MD_A_POST_DATE', '');

define('_MD_A_TITLE_CATEGORY_CONFIG', 'ߥ˥ƥƥ');
define('_MD_A_TITLE_IMAGE_CONFIG', '');
define('_MD_A_TITLE_FILE_CONFIG', 'ե');
define('_MD_A_TITLE_ACCESS_LOG', '');

define('_MD_A_CATEGORY1', '楫ƥ');
define('_MD_A_CATEGORY2', 'ƥ');
define('_MD_A_CATEGORY_NAME', 'ƥ̾');
define('_MD_A_CATEGORY_ORDER', 'ɽ');
define('_MD_A_CATEGORY_LIST', '');
define('_MD_A_CATEGORY_OPERATION', '');
define('_MD_A_CATEGORY_EDIT', 'ѹ');
define('_MD_A_CATEGORY_DEL', '');
define('_MD_A_CATEGORY_ADD', 'ɲ');
define('_MD_A_CATEGORY_NAME_NG', 'ƥ̾ϤƤ');
define('_MD_A_CATEGORY_ORDER_NG', 'ɽϤƤ');
define('_MD_A_CATEGORY_ADD_OK', 'ƥɲäޤ');
define('_MD_A_CATEGORY_ADD_NG', 'ƥɲä˼Ԥޤ');
define('_MD_A_CATEGORY_EDIT_OK', 'ƥѹޤ');
define('_MD_A_CATEGORY_EDIT_NG', 'ƥѹ˼Ԥޤ');
define('_MD_A_CATEGORY_DEL_OK', 'ƥޤ');
define('_MD_A_CATEGORY_DEL_NG', 'ƥκ˼Ԥޤ');
define('_MD_A_CATEGORY_DEL_CONFIRM', '楫ƥȡб뾮ƥƺޤ\\n\\nƤǤ');

define('_MD_A_IMAGE', '');
define('_MD_A_IMAGE_SIZE', '');
define('_MD_A_IMAGE_AUTHOR', 'Ƽ');
define('_MD_A_IMAGE_REF', ' ');
define('_MD_A_IMAGE_DELETE', ' ');
define('_MD_A_IMAGE_DELETE_OK', '򤵤줿ޤ');
define('_MD_A_IMAGE_SELECT_NG', '򤵤Ƥޤ');
define('_MD_A_IMAGE_DELETE_NG', 'ǤޤǤ');

define('_MD_A_FILE_NAME', 'ե̾');
define('_MD_A_FILE_SIZE', '');
define('_MD_A_FILE_AUTHOR', 'Ƽ');
define('_MD_A_FILE_REF', ' ');
define('_MD_A_FILE_DELETE', ' ');
define('_MD_A_FILE_DELETE_OK', '򤵤줿եޤ');
define('_MD_A_FILE_SELECT_NG', 'ե뤬򤵤Ƥޤ');
define('_MD_A_FILE_DELETE_NG', 'եǤޤǤ');

define('_MD_A_ACCESS_USER', '桼̾');
define('_MD_A_ACCESS_COMMU', 'ߥ˥ƥ̾');
define('_MD_A_ACCESS_DATE', '');

define('_CM_PAGE_SELECT_DESC', '%d %d-%dɽ');

?>

==> xsns_1.0.4.zip: xsns_1.0.4/xoops_trust_path/modules/xsns/language/japanese/admin.php <==
<?php

define('_MD_A_POST_DATE', '');

define('_MD_A_PERM_ERR', 'Υǥ쥯ȥ򡢥Фˤ񤭹ߤǽǺƤ<br>UNIX/LINUXФ򤴻Ѥξ硢ƥǥ쥯ȥΥѡߥå777ꤷƤ');

define('_MD_A_PERM_ERR2', '<span style="color:#ff0000;">PHPե⡼ɴĶǼ¹ԤƤ뤿ᡢޥڡ֤¹ԤǤޤǤ</span>');

define('_MD_A_TITLE_CATEGORY_CONFIG', 'ߥ˥ƥƥ');
define('_MD_A_TITLE_IMAGE_CONFIG', '');
define('_MD_A_TITLE_FILE_CONFIG', 'ե');
define('_MD_A_TITLE_ACCESS_LOG', '');

define('_MD_A_CATEGORY1', '楫ƥ');
define('_MD_A_CATEGORY2', 'ƥ');
define('_MD_A_CATEGORY_NAME', 'ƥ̾');
define('_MD_A_CATEGORY_ORDER', 'ɽ');
define('_MD_A_CATEGORY_LIST', '');
define('_MD_A_CATEGORY_OPERATION', '');
define('_MD_A_CATEGORY_EDIT', 'ѹ');
define('_MD_A_CATEGORY_DEL', '');
define('_MD_A_CATEGORY_ADD', 'ɲ');
define('_MD_A_CATEGORY_NAME_NG', 'ƥ̾ϤƤ');
define('_MD_A_CATEGORY_ORDER_NG', 'ɽϤƤ');
define('_MD_A_CATEGORY_ADD_OK', 'ƥɲäޤ');
define('_MD_A_CATEGORY_ADD_NG', 'ƥɲä˼Ԥޤ');
define('_MD_A_CATEGORY_EDIT_OK', 'ƥѹޤ');
define('_MD_A_CATEGORY_EDIT_NG', 'ƥѹ˼Ԥޤ');
define('_MD_A_CATEGORY_DEL_OK', 'ƥޤ');
define('_MD_A_CATEGORY_DEL_NG', 'ƥκ˼Ԥޤ');
define('_MD_A_CATEGORY_DEL_CONFIRM', '楫ƥȡб뾮ƥƺޤ\\n\\nƤǤ');

define('_MD_A_IMAGE', '');
define('_MD_A_IMAGE_SIZE', '');
define('_MD_A_IMAGE_AUTHOR', 'Ƽ');
define('_MD_A_IMAGE_REF', ' ');
define('_MD_A_IMAGE_DELETE', ' ');
define('_MD_A_IMAGE_DELETE_OK', '򤵤줿ޤ');
define('_MD_A_IMAGE_SELECT_NG', '򤵤Ƥޤ');
define('_MD_A_IMAGE_DELETE_NG', 'ǤޤǤ');

define('_MD_A_FILE_NAME', 'ե̾');
define('_MD_A_FILE_SIZE', '');
define('_MD_A_FILE_AUTHOR', 'Ƽ');
define('_MD_A_FILE_REF', ' ');
define('_MD_A_FILE_DELETE', ' ');
define('_MD_A_FILE_DELETE_OK', '򤵤줿եޤ');
define('_MD_A_FILE_SELECT_NG', 'ե뤬򤵤Ƥޤ');
define('_MD_A_FILE_DELETE_NG', 'եǤޤǤ');

define('_MD_A_ACCESS_USER', '桼̾');
define('_MD_A_ACCESS_COMMU', 'ߥ˥ƥ̾');
define('_MD_A_ACCESS_DATE', '');

define('_CM_PAGE_SELECT_DESC', '%d %d-%dɽ');

?>
